################################################################################
# Functions to extract citations fron the supplementary data items that are subsets of the PBDB
# Ádám T. Kocsis
# 2021-08-01 Erlangen
########################################----------------------------------------

#' Function to extract contribution number from a data file name, where the contribution
#' number is the first part of the name.
#' @param name The character vector of filenames
OfficialNo <- function(name){
	as.numeric(unlist(lapply(strsplit(name, "_"), function(x) x[1])))
}

#' Function to get the extension of the file
Extension <- function(name){
	unlist(lapply(strsplit(name, "\\."), function(x) x[length(x)]))
}

# valid columns for references
references <- c("reference_no", "occurrence.reference_no", "collection.reference_no", "Reference_number")

#' Function to load a specific data file using its corresponding entries in the data table.
#'
#' @param datafile Single character string.
#' @param register data.frame, the tabulation of official PBDB conntributions
#' @param no The official publication number
#' @param debug logical - Should a column-wise tabulation be returned? 
GetCited <- function(datafile, register, no=NULL, debug=FALSE){
	# only if the same directory
	if(is.null(no))  no <- OfficialNo(datafile)

	# get the corresponding entries
	details<<- register[which(register$official==no),]

	# load the datafile in any way you can
	dat <- LoadData(datafile, details)

	# 1. find the reference number columns
	given <-as.character(details[,c("reference_column", "occ_reference_column") ])
	all  <- unique(c(references, given))
		
	# # search for these
	refCols <- colnames(dat)[colnames(dat)%in%all]

	if(length(refCols)>0){
		# get a list for the different columns
		what <- list()
		for(i in 1:length(refCols)){
			# get all the entries
			current <- unique(dat[,refCols[i]])
			current <- current[!is.na(current)]

			# save
			what[[i]] <- sort(current)
		}
		# store the columns too
		names(what) <- refCols

		# make sure to return everything in a simple vector
		if(debug){
			what$all <- sort(unique(unlist(what)))
		}else{
			what <- sort(unique(unlist(what)))
		}

		# and finally return this
		return(what)
	}else{
		return(NULL)
	}
		
}

# Swithc wrapper to load the file
LoadData <- function(datafile, details){

	# file extension
	ext <- Extension(datafile)


	# loading switch:
	switch(ext, 
	csv={
		dat <<- Load.csv(datafile, details)			

	},
	RData={
		dat<<- load(datafile)
	},
		dat <<-NULL
	

	)

	# return a single file
	return(dat)

}

# function to readin csv filesf
#' @param datafile the path to the data file that needs to be loaded
#' @param details the row from the summary table
#' @return The single loaded object.
Load.csv <- function(datafile, details){
	# argumentation
	arg <- list(file=datafile)

	# separator, comma or entry
	if(details$separator=="comma" | details$separator==""){
		arg$sep <- ","
	}
	if(details$separator=="semicolon"){
		arg$sep <- ";"
	}

	# assume that header is there
	arg$header <- TRUE
	
	# skipping rows
	# try to convert to numeric to if this is valid
	suppressWarnings(arg$skip <- as.numeric(details$skiprows))

	# in case an invalid entry is there
	if(is.na(arg$skip)) arg$skip <- 0
	
	dat <- do.call("read.csv", arg)

}
