## ---------------------------
## Code to calculate display items and statistics for
## the manuscript on data citation practices in paleontology
## Adam T. Kocsis, Nussaïbah B. Raja, and Jansen A. Smith
## CC-BY 4.0
## ---------------------------

# set working directory to downloaded Zenodo Repository
setwd("/Users/jansena.smith/Dropbox/Research Projects/Citations in science/friday-main2/Paleobiology (submission)/New Zenodo Repo")

library(viridis)
library(tidyverse)
## if using harmonic means, need to account for zeros
## psych does not but lmomco does
library(lmomco)

# Data ############################################################################

########################################----------------------------------------
# A. PaleobioDB official contributions 
# the official contributions from the pbdb
pbdb <- read.csv("1_pbdb_publication_information.csv")
pbdb_years <- read.csv("5_pbdb_publications_years.csv")[, c("official", "pubyr")]

# assume this year for In Press
pbdb_years$pubyr[is.na(pbdb_years$pubyr)] <- 2022

# merging
pbdb <- merge(pbdb, pbdb_years, by="official")

# the number of pbdb official publciations
nPBDB <- nrow(pbdb)

# the duration of the papers (i.e., time in existance)
pbdb$duration <- (2022-pbdb$pubyr)

# rates of citation
pbdb$rate <- pbdb$cite_n/pbdb$duration #citations per year
pbdb$rate[is.infinite(pbdb$rate)] <- NA

########################################----------------------------------------
# B. Citations from scholar 
# Citations scraped from scholar
citation <- read.csv("4_provisioning_publication_citations.csv")

# remove those paper's where this was not successful
citation <- citation[!is.na(citation$ncite),]

## original was 49999, trimmed to 47122

# remove bad citation record
citation <- citation[citation$reference_no!="10294",]

########################################----------------------------------------
# C. The implied citations in the deposited datasets 
# Loading lists of data-provisioning publications used in PBDB publications
load("14_raw_PBDB_data.RData")

refs <- lapply(refs, function(x) unique(unlist(x))) #flatten list and get unique refs

validInput <- sum(unlist(lapply(refs, function(x){
	!is.null(x)
})))

# the number of pbdb official publications that we assessed
nAssessed <- length(refs)
## up to 151 with new data *final*

# a simple multiplier for extrapolating to full dataset
extra <- nPBDB/nAssessed

# This needs cleaning
all_refs <- unlist(refs)

# some of the entries were not reference numbers
all_refs <- suppressWarnings(all_refs[!is.na(as.numeric(all_refs))])

# Primary papers cited in  datasets
citation <- citation[citation$reference_no %in% unique(all_refs),] 

# new citations per primary paper 
summ <- table(all_refs)
add.df <-setNames(data.frame(summ), c("reference_no", "add"))

# All information about primary publications in a single table
# total citation information
all <- merge(citation, add.df)

# Extrapolated to the whole PBDB
all$addExtra <- all$add*extra

# adding the total citations (original+pbdb)
all$tot <- all$ncites + all$add
all$totExtra <- all$ncites + all$addExtra
all$duration <- (2022-all$pubyr)

# rates of citation
all$originalRate <- all$ncites/all$duration
all$newRate <- all$tot/all$duration
all$newRateExtra <- all$totExtra/all$duration

## adding year to when a particular reference was used
## manipulating data to get out year-by-year citations for JIF
## removing any list that is NULL
refsValid <- refs[!sapply(refs, is.null)] # trims to 112 from 151
## creating data.frame to collect for loop outputs
referYear <- data.frame()  ## returns 598782 rows - instances of citation
for(i in 1:length(refsValid)){
  pbPub <- as.data.frame(unlist(refsValid[i], use.names = FALSE))
  pbPub$official <- as.integer(names(refsValid[i]))
  colnames(pbPub) <- c("refID", "official")
  referYear <- rbind(referYear, pbPub)
}
## adding the year that the PBDB paper was published
## now data.frame has a row for every time a data-provisioning data is used
## by any PBDB paper
referYear <- left_join(referYear, pbdb_years, by = "official")
colnames(referYear) <- c("reference_no", "officialPBDB", "pubyrPBDB")
### adding information about each refID (data-provisioing pub)
# some of the entries were not reference numbers (e.g., alphanumeric)
# trims 12 rows
referYear <- suppressWarnings(referYear[!is.na(as.numeric(referYear$reference_no)),])

# Adding all other citation information
all$reference_no <- as.character(all$reference_no)
## something goes wrong when converting reference_no to integer in referYear so doing the opposite

referYear <- left_join(referYear, all, by = "reference_no")
## some items with a "reference_no" are not connected to citation - trimmed to our citation list
referYear <- suppressWarnings(referYear[!is.na(referYear$primary_reference),])
## removes 49022 rows where there were NA values, now 549748

## adding column for time between PBDB use and publication or provisioning paper
referYear$elapsed <- referYear$pubyrPBDB - referYear$pubyr

## Only preceding 2 years are used for JIF calculation, so:
referJIF <- referYear %>%
  filter(elapsed == 1 | elapsed == 2)
## only 11835 times that a data-provisioning paper is cited within two years of publication

########################################----------------------------------------
# D. Extracting neglected citations for all paleontological journals
### not terribly efficient but is effective
### The results of this exercise are compiled in the file "7_paleo_journal_JIFcalculation.csv"
### The JIF (journal impact factor) analysis was conducted secondarily, with contributions from 
### multiple authors. Data were aggregated manually using this code.

jvp <- referJIF[grep(". Journal of Vertebrate Paleontology", referJIF$primary_reference),]
jvpCites <- jvp %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
jvpCites$journal <- "JOURNAL OF VERTEBRATE PALEONTOLOGY"

acta <- referJIF[grep(". Acta Palaeontologica Polonica", referJIF$primary_reference),]
actaCites <- acta %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
actaCites$journal <- "ACTA PALAEONTOLOGICA POLONICA"

palElect <- referJIF[grep(". Palaeontologia Electronica", referJIF$primary_reference),]
palElectCites <- palElect %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
palElectCites$journal <- "PALAEONTOLOGIA ELECTRONICA"

jPaleo <- referJIF[grep(". Journal of Paleontology", referJIF$primary_reference),]
jPaleoCites <- jPaleo %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
jPaleoCites$journal <- "JOURNAL OF PALEONTOLOGY"

jSysPal <- referJIF[grep(". Journal of Systematic Palaeontology", referJIF$primary_reference),]
jSysPalCites <- jSysPal %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
jSysPalCites$journal <- "JOURNAL OF SYSTEMATIC PALAEONTOLOGY"

cretaRes <- referJIF[grep(". Cretaceous Research", referJIF$primary_reference),]
cretaResCites <- cretaRes %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
cretaResCites$journal <- "CRETACEOUS RESEARCH"

palaeo <- referJIF[grep(". Palaeontology", referJIF$primary_reference),]
palaeoCites <- palaeo %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
palaeoCites$journal <- "PALAEONTOLOGY"

ppp <- referJIF[grep(". Palaeogeography, Palaeoclimatology, Palaeoecology", referJIF$primary_reference),]
ppp2 <- referJIF[grep(". P3", referJIF$primary_reference),]
ppp <- rbind(ppp, ppp2)
pppCites <- ppp %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
pppCites$journal <- "PALAEOGEOGRAPHY PALAEOCLIMATOLOGY PALAEOECOLOGY"

palW <- referJIF[grep(". Palaeoworld", referJIF$primary_reference),]
palWCites <- palW %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
palWCites$journal <- "Palaeoworld"

papPal <- referJIF[grep(". Papers in Palaeontology", referJIF$primary_reference),]
papPalCites <- papPal %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
papPalCites$journal <- "Papers in Palaeontology"

palBio <- referJIF[grep(". Paleobiology", referJIF$primary_reference),]
palBioCites <- palBio %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
palBioCites$journal <- "PALEOBIOLOGY"

zoo <- referJIF[grep(". Zootaxa", referJIF$primary_reference),]
zooCites <- zoo %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
zooCites$journal <- "Zootaxa"

neues <- referJIF[grep(". Neues", referJIF$primary_reference),]
neuesCites <- neues %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
neuesCites$journal <- "NEUES JAHRBUCH FUR GEOLOGIE UND PALAONTOLOGIE-ABHANDLUNGEN"

microPal <- referJIF[grep(". Micropal", referJIF$primary_reference),]
microPalCites <- microPal %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
microPalCites$journal <- "MICROPALEONTOLOGY"
## none

marmicroPal <- referJIF[grep(". Marine Micropal", referJIF$primary_reference),]
marmicroPalCites <- marmicroPal %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
marmicroPalCites$journal <- "MARINE MICROPALEONTOLOGY"
## none

leth <- referJIF[grep(". Lethaia", referJIF$primary_reference),]
lethCites <- leth %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
lethCites$journal <- "LETHAIA"

forRes <- referJIF[grep(". Journal of Foram", referJIF$primary_reference),]
forResCites <- forRes %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
forResCites$journal <- "JOURNAL OF FORAMINIFERAL RESEARCH"

hisBio <- referJIF[grep(". Historical Biology", referJIF$primary_reference),]
hisBioCites <- hisBio %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
hisBioCites$journal <- "HISTORICAL BIOLOGY"

geobios <- referJIF[grep(". Geobios", referJIF$primary_reference),]
geobiosCites <- geobios %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
geobiosCites$journal <- "GEOBIOS"

facies <- referJIF[grep(". Facies", referJIF$primary_reference),]
faciesCites <- facies %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
faciesCites$journal <- "FACIES"

earth <- referJIF[grep(". Earth and", referJIF$primary_reference),]
earthCites <- earth %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
earthCites$journal <- "Earth and Environmental Science Transactions of the Royal Society of Edinburgh"

comptes <- referJIF[grep(". Comptes", referJIF$primary_reference),]
comptesCites <- comptes %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
comptesCites$journal <- "COMPTES RENDUS PALEVOL"

ameghi <- referJIF[grep(". Ameghi", referJIF$primary_reference),]
ameghiCites <- ameghi %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
ameghiCites$journal <- "AMEGHINIANA"

palaios <- referJIF[grep(". Palaios", referJIF$primary_reference),]
palaiosCites <- palaios %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
palaiosCites$journal <- "PALAIOS"

procGeo <- referJIF[grep(". Proceedings of the Geo", referJIF$primary_reference),]
procGeoCites <- procGeo %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
procGeoCites$journal <- "PROCEEDINGS OF THE GEOLOGISTS ASSOCIATION"

paleoJourn <- referJIF[grep(". Paleontological Journal", referJIF$primary_reference),]
paleoJournCites <- paleoJourn %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
paleoJournCites$journal <- "PALEONTOLOGICAL JOURNAL"

revPalBo <- referJIF[grep(". Review of Palaeobo", referJIF$primary_reference),]
revPalBoCites <- revPalBo %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
revPalBoCites$journal <- "REVIEW OF PALAEOBOTANY AND PALYNOLOGY"
## 1 result

# VEGETATION HISTORY AND ARCHAEOBOTANY
vegHis <- referJIF[grep(". Vegetation", referJIF$primary_reference),]
## 1 result

# Paleoceanography and Paleoclimatology
palOceClim <- referJIF[grep(". Paleoceano", referJIF$primary_reference),]
## 2 results

# STRATIGRAPHY AND GEOLOGICAL CORRELATION
stratGeo <- referJIF[grep(". Stratigraphy and Geo", referJIF$primary_reference),]
## 3 results

# PALYNOLOGY
palyno <- referJIF[grep(". Palynology", referJIF$primary_reference),]
## 1 result

# RIVISTA ITALIANA DI PALEONTOLOGIA E STRATIGRAFIA
rivista <- referJIF[grep(". Rivista Ital", referJIF$primary_reference),]
rivistaCites <- rivista %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
rivistaCites$journal <- "RIVISTA ITALIANA DI PALEONTOLOGIA E STRATIGRAFIA"

#Palaeontographica Abteilung B-Palaeophytologie Palaeobotany-Palaeophytology
#None

palAbteil <- referJIF[grep(". Palaeontographica Abteilung", referJIF$primary_reference),]
palAbteilCites <- palAbteil %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
palAbteilCites$journal <- "PALAEONTOGRAPHICA ABTEILUNG A-PALAOZOOLOGIE-STRATIGRAPHIE"

ichnos <- referJIF[grep(". Ichnos", referJIF$primary_reference),]
ichnosCites <- ichnos %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
ichnosCites$journal <- "Ichnos"

gff <- referJIF[grep(". GFF", referJIF$primary_reference),]
# 4 results

geodiv <- referJIF[grep(". Geodiversitas", referJIF$primary_reference),]
geodivCites <- geodiv %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
geodivCites$journal <- "Geodiversitas"

bullGeo <- referJIF[grep(". Bulletin of Geo", referJIF$primary_reference),]
bullGeoCites <- bullGeo %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
bullGeoCites$journal <- "BULLETIN OF GEOSCIENCES"

alcher <- referJIF[grep(". Alcheringa", referJIF$primary_reference),]
alcherCites <- alcher %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
alcherCites$journal <- "ALCHERINGA"

palPath <- referJIF[grep("Paleopathology", referJIF$primary_reference),]
# None

jPalGeo <- referJIF[grep("Journal of Palaeogeography", referJIF$primary_reference),]
jPalGeoCites <- jPalGeo %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
jPalGeoCites$journal <- "Journal of Palaeogeography"

jMicroPal <- referJIF[grep(". Journal of Micro", referJIF$primary_reference),]
# None

fossRec <- referJIF[grep(". Fossil Record", referJIF$primary_reference),]
fossRecCites <- fossRec %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
fossRecCites$journal <- "Fossil Record"

carnets <- referJIF[grep("Carnets de", referJIF$primary_reference),]
carnetsCites <- carnets %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
carnetsCites$journal <- "Carnets de Geologie"

bollItal <- referJIF[grep(". Bollettino della", referJIF$primary_reference),]
bollItalCites <- bollItal %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
bollItalCites$journal <- "BOLLETTINO DELLA SOCIETA PALEONTOLOGICA ITALIANA"

annales <- referJIF[grep(". Annales de P", referJIF$primary_reference),]
annalesCites <- annales %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
annalesCites$journal <- "ANNALES DE PALEONTOLOGIE"

annalsCar <- referJIF[grep(". Annals of C", referJIF$primary_reference),]
annalsCarCites <- annalsCar %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
annalsCarCites$journal <- "ANNALS OF CARNEGIE MUSEUM"

afrInv <- referJIF[grep(". African Invert", referJIF$primary_reference),]
# 3 results

socInd <- referJIF[grep("Society of India", referJIF$primary_reference),]
socIndCites <- socInd %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
socIndCites$journal <- "JOURNAL OF THE PALAEONTOLOGICAL SOCIETY OF INDIA"

strat <- referJIF[grep(". Stratigraphy", referJIF$primary_reference),]
## search fail - too common

revBras <- referJIF[grep("Revista Brasil", referJIF$primary_reference),]
revBrasCites <- revBras %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
revBrasCites$journal <- "REVISTA BRASILEIRA DE PALEONTOLOGIA"

palZ <- referJIF[grep("PalZ", referJIF$primary_reference),]
palZCites <- palZ %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
palZCites$journal <- "PalZ"

palRes <- referJIF[grep(". Paleontological Research", referJIF$primary_reference),]
palResCites <- palRes %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
palResCites$journal <- "Paleontological Research"

swissPal <- referJIF[grep(". Swiss Journal", referJIF$primary_reference),]
swissPalCites <- swissPal %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
swissPalCites$journal <- "Swiss Journal of Palaeontology"

palPal <- referJIF[grep("Palaeobiodiversity and Palaeoenvironments", referJIF$primary_reference),]
palPalCites <- palPal %>%
  group_by(pubyrPBDB, elapsed) %>%
  summarise(count = n())
palPalCites$journal <- "Palaeobiodiversity and Palaeoenvironments"


########################################----------------------------------------
# E. Analysis of omitted citations to data-provisioning publications using harmonic mean

### Comparing citation frequencies
hmOrigRate <- harmonic.mean(all$originalRate)
hmOrigRateOut <- as.numeric(hmOrigRate[1])
mean(all$originalRate)
pbdbTrim <- pbdb[!is.na(pbdb$rate),]
mean(pbdbTrim$rate)

## Generate bootstrap resampling distribution of differences in test statistic
## x sample 1, numeric vector
## y sample 2, numeric vector
## FUN function to calculate statistic
## trials number of bootstrap trials
## counter should a loop counter be displayed?
## ... arguments passed to FUN
## manipulating harmonic.mean from lmomco to return just a numeric value for hm
hmJAS <- function (x) {
  x <- x[!is.na(x)]
  n <- length(x)
  x.nonzero <- x[x != 0]
  n.zero <- n - length(x.nonzero)
  correction <- (n - n.zero)/n
  HM <- (1/mean(1/x.nonzero)) * correction
  #z <- list(harmean = HM, correction = correction, source = "harmonic.mean")
  #return(z)
  return(HM)
}

BootDiff <- function(x, y, FUN=hmJAS, trials=10000, counter=TRUE,  ...){
  # resampling pool
  pool <- c(x,y)
  
  # enforce function lookup
  FUN <- match.fun(FUN)
  
  # Results 
  res <- rep(NA, trials)
  
  # iteration
  for(i in 1:trials){
    # Generate new samples, original structure
    newX <- sample(pool, length(x), replace=TRUE)
    newY <- sample(pool, length(y), replace=TRUE)
    
    # Calculate new statistics
    xStat <- FUN(newX, ...)
    yStat <- FUN(newY, ...)
    
    # store stats
    res[i] <- xStat-yStat
    
    # display loop counter
    if(counter) cat(i, "\r"); flush.console()
  }
  
  return(res)
}

## Comparing PBDB to the temporally constrained, 2001 and later list (n ~20,000)
later <- all[all$pubyr>=min(pbdb$pubyr), ]
d <- BootDiff(later$originalRate, pbdbTrim$rate, FUN=hmJAS)
xyDiff <- hmJAS(pbdbTrim$rate) - hmJAS(later$originalRate)
hist(d, xlim = c(-xyDiff-1, xyDiff+1))
abline(v = xyDiff, col = "red")
table(xyDiff > d)

dNew <- BootDiff(later$newRate, pbdbTrim$rate, FUN=hmJAS)
xyDiffnew <- hmJAS(pbdbTrim$rate) - hmJAS(later$newRate)
hist(dNew, xlim = c(-xyDiffnew-1, xyDiffnew+1))
abline(v = xyDiffnew, col = "red")
table(xyDiffnew > dNew)

dExtra <- BootDiff(later$newRateExtra, pbdbTrim$rate, FUN=hmJAS)
xyDiffExtra <- hmJAS(pbdbTrim$rate) - hmJAS(later$newRateExtra)
hist(dExtra, xlim = c(xyDiffExtra-1, -xyDiffExtra+1))
abline(v = xyDiffExtra, col = "red")
table(xyDiffExtra > dExtra)

## Simple summary statistics, using whole temporal scope
outMean <- c(mean(all$originalRate), mean(all$newRate), mean(all$newRateExtra))
outMedian <- c(median(all$originalRate), median(all$newRate), median(all$newRateExtra))
outHM <- c(hmJAS(all$originalRate), hmJAS(all$newRate), hmJAS(all$newRateExtra))
outPBDD <- c(mean(pbdbTrim$rate), median(pbdbTrim$rate), hmJAS(pbdbTrim$rate))
### adding mean absolute deviation
madPBDB <- mad(pbdbTrim$rate)
quantile(pbdbTrim$rate)

## statistics using the temporally constrained list
outMeanLater <- c(mean(later$originalRate), mean(later$newRate), mean(later$newRateExtra))
outMedianLater <- c(median(later$originalRate), median(later$newRate), median(later$newRateExtra))
madMedianLater <- c(mad(later$originalRate), mad(later$newRate), mad(later$newRateExtra))
outHMLater <- c(hmJAS(later$originalRate), hmJAS(later$newRate), hmJAS(later$newRateExtra))
quantile(later$originalRate)
quantile(later$newRateExtra)


## All data - statistical comparisons
wilcox.test(pbdb$rate, all$originalRate) ## medians are not the same
wilcox.test(pbdb$rate, all$newRate) ## medians are not the same
wilcox.test(pbdb$rate, all$newRateExtra) ## medians are not the same
## Temporally constrained, 2001 and later
wilcox.test(pbdb$rate, later$originalRate) ## medians are not the same
wilcox.test(pbdb$rate, later$newRate) ## medians are not the same
wilcox.test(pbdb$rate, later$newRateExtra) ## medians are the same********

################################################################################
########################################----------------------------------------
# F. Data visualization 

## Theme modified from code by Marina Rillo
tema <-  theme_bw(base_size = 18) +
  theme(axis.title = element_text(size = 20),
        axis.text = element_text(size = 16),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        strip.placement = "outside",
        strip.text = element_text(size = 16),
        strip.background = element_blank(), 
        legend.text = element_text(size = 10),
        legend.title = element_text(size = 14),
        legend.background = element_rect(linetype="solid", colour ="black", size = 0.3))

ggplot() +
  geom_boxplot(data = pbdbTrim, aes(y = rate), width = 0.1, position(0.3)) +
  scale_x_discrete() +
  geom_boxplot(data = later, aes(y = originalRate)) +
  geom_boxplot(data = later, aes(y = newRate)) +
  geom_boxplot(data = later, aes(y = newRateExtra)) +
  ylab("Median Annual Citation Rate") +
  tema


### Contrasting primary and PBDB citations plots
  
# color palette

### Can use pre-made palette in chronosphere or other packages
# library(chronosphere)
# a <- gradinv(20)

# primary colors
pbdbCol <- "#E39581"
primaryCol<- "#8197C9"
primaryCol2 <- "#93bab8"
primaryCol3 <- "#80BAA7"

# rate contrast overall
# contrast contrast in overlapping part of age range (2001 and later)
# Code creates multiple versions of main text Figure 2, included for comparison 
later <- all[all$pubyr>=min(pbdb$pubyr), ]

pdf("rate_difference.pdf", width=12, height=8)

# contrast
plot(
  NULL, NULL,
  xlim=c(0.5,4),
  ylim=c(0, 18),
  ylab="Citation rate (number of citations/year)",
  xlab="",
  axes=F
)
box()
axis(2)

width <- 0.85

# pbdb Publications
center <- 1
boxplot(
  pbdb$rate, 
  add=T,
  at=center,
  axes=F,
  border=pbdbCol,
  width=width+0.05,
  outline=F, 
  col=paste0(pbdbCol, 44)
)
points(
  runif(nrow(pbdb), center-width/2, center+width/2), pbdb$rate,
  col=paste0(pbdbCol,44), cex=0.6, pch=16)


# Primary original
center <- 2.5 

# make a subset for plotting, 3000 points!
subPrim <- all[sample(1:nrow(all), 3000), ]
points(
  runif(nrow(subPrim), center-width/2, center+width/2), subPrim$originalRate,
  col=paste0(primaryCol,"10"), cex=0.6, pch=16)

boxplot(
  all$originalRate, 
  add=T,
  at=center,
  axes=F,
  border=primaryCol,
  width=width+0.05,
  col=paste0(primaryCol, 44),
  outline = F
)

# the original from 2001
center <- 3.5

# make a subset for plotting, number of points should be proportional at least!
subLater<- all[sample(1:nrow(all), round(nrow(subPrim)/nrow(all)*nrow(later))), ]
points(
  runif(nrow(subLater), center-width/2, center+width/2), subLater$originalRate,
  col=paste0(primaryCol2,"10"), cex=0.6, pch=16)

boxplot(
  later$originalRate, 
  add=T,
  at=center,
  axes=F,
  border=primaryCol2,
  width=width+0.05,
  col=paste0(primaryCol2, 44),
  outline = F
)

axis(1, at=c(1, 2.5, 3.5), label= c("PBDB official publications", "Primary literature", "Primary literature since 2001 (PBDB)"))
mtext(3, line=1, at=c(1, 2.5, 3.5), text=paste0("n = ",c(sum(!is.na(pbdb$rate)), nrow(all), nrow(later))))

dev.off()


# calculate citation rates in the offical pbdb publications
pdf("rate_increasePoint.pdf", width=12, height=8)

# contrast
plot(
  NULL, NULL,
  xlim=c(0.5,5),
  ylim=c(0, 18),
  ylab="Citation rate (number of citations/year)",
  xlab="",
  axes=F
)
box()
axis(2)

width <- 0.85

# pbdb Publications
center <- 1
boxplot(
  pbdb$rate, 
  add=T,
  at=center,
  axes=F,
  border=pbdbCol,
  width=width+0.05,
  outline=F, 
  col=paste0(pbdbCol, 44)
)
points(
  runif(nrow(pbdb), center-width/2, center+width/2), pbdb$rate,
  col=paste0(pbdbCol,44), cex=0.6, pch=16)

# primary
center <- 2.5
points(
  runif(nrow(subLater), center-width/2, center+width/2), subLater$originalRate,
  col=paste0(primaryCol,"20"), cex=0.6, pch=16)

boxplot(
  later$originalRate, 
  add=T,
  at=center,
  axes=F,
  border=primaryCol,
  width=width+0.05,
  col=paste0(primaryCol, 44),
  outline = F
)

# primary with additions
center <- 3.5
points(
  runif(nrow(subLater), center-width/2, center+width/2), subLater$newRate,
  col=paste0(primaryCol2,"20"), cex=0.6, pch=16)

boxplot(
  later$newRate, 
  add=T,
  at=center,
  axes=F,
  border=primaryCol2,
  width=width+0.05,
  col=paste0(primaryCol2, 44),
  outline = F
)

# primary with additions (extrapolated)
center <- 4.5
points(
  runif(nrow(subLater), center-width/2, center+width/2), subLater$newRateExtra,
  col=paste0(primaryCol3,"20"), cex=0.6, pch=16)

boxplot(
  later$newRateExtra, 
  add=T,
  at=center,
  axes=F,
  border=primaryCol3,
  width=width+0.05,
  col=paste0(primaryCol3, 44),
  outline = F
)

axis(1, at=c(1, 2.5, 3.5, 4.5), label= c("PBDB official publications", "Primary literature (since 2001)", "Primary literature\n(2001+, additions)",  "Primary literature\n(2001+, additions, extrapolated)") )

mtext(3, line=1, at=c(1, 2.5, 3.5,4.5), text=c(
  paste0("n = ", sum(!is.na(pbdb$rate))),
  paste0("n = ", nrow(later), ", k = 0 "), 
  paste0("n = ", nrow(later), ", k = ", validInput), 
  paste0("n = ", nrow(later), ", k = ->", nPBDB))
)

dev.off()


###############################################
## Plotting Journal Impact Factor and trends ##
###############################################
## Used for Figure 3 in the main text

## All Paleo Journals from WoS
PalJo <- read.csv("6_paleo_journal_data.csv")

PalJoSum <- PalJo %>%
  group_by(Year) %>%
  summarise(paleoCitations = sum(totalCitations, na.rm = TRUE),
            citablePaleo = sum(as.numeric(citableItems), na.rm = TRUE))

## This csv draws on the information above, added manually because
## already doing so to extract other information from WoS for JIF
jif <- read.csv("7_paleo_journal_JIFcalculation.csv")

## Some broad summary statistics
## Looking at ALL data
jifSumm <- jif %>%
  group_by(Journal) %>%
  summarize(minDiff = min(JIFdiff),
            maxDiff = max(JIFdiff),
            medianDiff = median(JIFdiff),
            minDiffPerc = min(percChange),
            maxDiffPerc = max(percChange),
            medianDiffPerc = median(percChange),
            yearsData = n())
jifSumm$bin <- "allYears"

## trimming data to last decade
## omitting 2021 and 2020 because we do not have complete data for these years
jif1019 <- jif %>%
  filter(Year > 2009 & Year < 2020) 
  
jifSumm1019 <- jif1019 %>%
  group_by(Journal) %>%
  summarize(minDiff = min(JIFdiff),
            maxDiff = max(JIFdiff),
            medianDiff = median(JIFdiff),
            minDiffPerc = min(percChange),
            maxDiffPerc = max(percChange),
            medianDiffPerc = median(percChange),
            yearsData = n())
jifSumm1019$bin <- "1019"

jifSummAll <- rbind(jifSumm, jifSumm1019)

## extra output for those interested
write.csv(jifSummAll, file = "JIFchangesBinned", row.names = FALSE)

## Generate Figure 3a in the main text
jif19 <- jif %>%
  filter(Year == 2019)

ggplot(data = jif1019, mapping = aes(x = as.factor(Year), y = percChange)) +
  geom_boxplot(outlier.shape = NA) +
  geom_point(position = position_jitter(width = 0.25)
             #, alpha = 0.5, size = 0.5
             ) + 
  ylim(c(0,60)) +  ## removes 1 outlier at 172%
  xlab("Publication Year") + ylab("Percent Change in Journal Impact Factor") + 
  tema
  
## Generate Figure 3b in the main text
focalJo <- c("PALEONTOLOGICAL JOURNAL",
             "Fossil Record",  
             "PALEONTOLOGICAL RESEARCH",
             "JOURNAL OF PALEONTOLOGY",
             "PALAEONTOLOGY",
             "CRETACEOUS RESEARCH",
             "ACTA PALAEONTOLOGICA POLONICA", 
             "RIVISTA ITALIANA DI PALEONTOLOGIA E STRATIGRAFIA", 
             "ALCHERINGA",
             "JOURNAL OF VERTEBRATE PALEONTOLOGY") 
## top ten median percent changers, with full data (10 years)
## omitting some of the big changers with fewer years of data (e.g., PalZ, Swiss JP)

jif1019Top <- jif1019 %>%
  filter(Journal %in% focalJo)

jif1019TopSumm <- jif1019Top %>%
  group_by(Year) %>%
  summarize(meanPercInc = mean(percChange),
            medianPercInc = median(percChange),
            meanInc = mean(JIFdiff),
            medianInc = median(JIFdiff))

## plotting percent differences through time
jifChange <- ggplot(data = jif1019[which(jif1019$Journal %in% focalJo),], aes(x = Year)) +
  geom_point(aes(y = percChange, col = Journal),
             size = 0.75) + 
  geom_line(aes(y = percChange, col = Journal),
            size = 0.5, alpha = 0.75) + 
  # adding smoothing to visualize trend
  # geom_smooth(aes(y = percChange)) +
  scale_fill_brewer(palette = "Paired") +
  xlab("Publication Year") +
  ylab("Percent Difference in Journal Impact Factor") + 
  ylim(c(0,60)) +
  scale_color_discrete(labels=c("APP", "ALC", "CR", "FR", "JP", "JVP",
                               "PAL", "PJ", "PR", "RIPS")) +
  scale_x_discrete(labels=c("2010.0" = "2010", "2015.0" = "2015", "2019.0" = "2019")) +
  tema + theme(legend.position = c(0.15,0.65))

jifChange
g <- ggplot_build(jifChange)
unique(g$data[[1]]["colour"])

### All paleo journals
## Generate Figure 3c in the main text
ggplot(data = PalJoSum, mapping = aes(x = Year)) +
  geom_point(aes(y = citablePaleo)) +
  geom_line(aes(y = citablePaleo)) +
  xlab("Publication Year") + ylab("Citable Items in Paleontological Journals") +
  tema + theme(legend.position = "none")

## Generate Figure 3d in the main text
ggplot(data = PalJoSum, mapping = aes(x = Year)) +
  geom_point(aes(y = paleoCitations)) +
  geom_line(aes(y = paleoCitations)) +
  ylim(c(0,150000)) +
  scale_y_continuous(breaks = seq(0, 150000, 25000))  +
  xlab("Publication Year") + ylab("Citations to All Paleontological Journals") +
  tema + theme(legend.position = "none")

### Additional plots related to publication trends
## P3 a massive outlier
PalJo$citableItems <- as.numeric(PalJo$citableItems)
ggplot(data = PalJo
       #[which(PalJo$Journal != "PALAEOGEOGRAPHY PALAEOCLIMATOLOGY PALAEOECOLOGY"),]
       , mapping = aes(x = Year, col = Journal)) +
  geom_point(aes(y = totalCitations)) +
  geom_line(aes(y = totalCitations)) +
  xlab("Publication Year") + ylab("Citations to Paleontological Journals") +
  tema + theme(legend.position = "none")

ggplot(data = PalJo, mapping = aes(x = Year, col = Journal)) +
  geom_point(aes(y = citableItems)) +
  geom_line(aes(y = citableItems)) +
  xlab("Publication Year") + ylab("Citable Items in Paleontological Journals") +
  tema + theme(legend.position = "none")

###############################################################
################## Supplemental Figures #######################
###############################################################

### Paleobiology Database official publications
### code used to create Figure S1 in the supplementary material

pubs <- read.csv("8_pbdb_publications_suppFigure.csv")

## Types of publication per year:
pbdb_palette <- c("#50B1B0","#0F8787", "#0B6465",  
                  "#C1651E","#E98D47", "#FFAE71",
                  "#A26C95", "grey80")

pubs %>% 
  #filter(!(category=="inaccessible")) %>% 
  mutate(category = factor(category, levels = c("occurrence", "combination", 
                                                "partial", "method", "review",
                                                "verification", "other",
                                                "inaccessible"
  ))) %>% 
  ggplot(aes(fill=category, x = year)) +
  geom_bar(position = "stack") +
  scale_fill_manual(values = pbdb_palette) +
  labs(x = "Year", y = "Number of publications") +
  theme_minimal() + theme(legend.title = element_blank())


### This code generates Supplemental Figure S2
pdf("citations_year.pdf", width=12, height=8)
# the plotting limit 
ylimit <- 500

# plotting primary
plot(all$duration, all$ncites,
     xlab="Study age (years)",
     ylab="Number of citations in Google Scholar",
     xlim=c(0, 200),
     ylim=c(0,ylimit),
     pch=16, 
     col=paste0(primaryCol, "33"), xaxs="i", yaxs="i")

# above limit
high <- all[all$ncites>ylimit, ]
points(
  high$duration, rep(ylimit-3, nrow(high)),
  cex=0.6,
  pch=17, 
  col=paste0(primaryCol, ""),
  
)

# plotting PBDB
points(pbdb$duration, pbdb$cite_n,
       pch=16, 
       col=paste0(pbdbCol, "77")
)

highPBDB <- pbdb[pbdb$cite_n>ylimit, ]
points(
  highPBDB$duration, rep(ylimit-3, nrow(highPBDB)),
  cex=0.6,
  pch=17, 
  col=paste0(pbdbCol, ""),
  
)


# legend
legend("topright",
       col=c(primaryCol, pbdbCol, "gray70"),
       pch=c(16,16, 17), 
       legend=c("Primary literature", "PBDB official publications", paste0("Above ", ylimit)),
       inset=c(0.1, 0.1)
)

# overlapping interval
abline(v=21.5, lty=2, col="gray30")

dev.off()

### This code generates Supplemental Figure S3
# The increase in number of citations
pdf("new_citation.pdf", width=12, height=8)
plot(all$pubyr, all$add, xlab="Year", ylab="Occurrence of primary reference in analysis studies", 
     xlim=c(1800, 2022), pch=16, col="lightblue", ylim=c(0, 35))
# yearly averages
yearAdded <- tapply(INDEX=all$pubyr, X=all$add, mean)
lines(as.numeric(names(yearAdded)), yearAdded, col="red", lwd=2)
dev.off()


### Code for Supplemental Figure S4
## Number of data-provisioning publications cited in PBDB publications
refsCited <- referYear %>%
  group_by(officialPBDB, pubyrPBDB) %>%
  summarise(Count = n()) %>%
  filter(Count > 1)

ggplot(refsCited, aes(as.factor(pubyrPBDB), Count)) +
  geom_boxplot(outlier.shape = NA) +
  geom_point() +
  labs(y = "Number of data-provisioning publications cited", 
       x = "Year of PBDB publication") +
  tema


##############################################################################
## Additional visuals and analyses, not included in supplement or main text ##
##############################################################################
## Rate of citation over time
plot(all$pubyr, all$originalRate, xlab="years", ylab="Rate of citation", xlim=c(1800, 2022))
points(all$pubyr, all$newRate, col="red")


# all literature
# citation by type
citations<- rbind(
  data.frame(n = all$originalRate, state="1-original"), 
  data.frame(n = all$newRate, state="2-added"), 
  data.frame(n = all$newRateExtra, state="3-extrapolated"))

boxplot(n~ state, data=citations,
        ylim=c(0,10)
)

# increase? 
wilcox.test(all$originalRate, all$newRate)
plot(all$originalRate, all$newRate,
     xlab="Citation/year without PBDB",
     ylab="Citation/year with PBDB",
     log="xy"
)

median(all$newRate)-median(all$originalRate)
median(all$newRateExtra)-median(all$originalRate)


# number of data-provisioning publications each year
pdf("primary_publications.pdf", width=12, height=8)
yearlyPrimary <- table(citation$pubyr)
plot(
  as.numeric(names(yearlyPrimary)), 
  as.numeric(yearlyPrimary), 
  type="n",
  ylim=c(0, 1200),
  xlim=c(1800, 2020.8),
  xlab="Year of publication",
  ylab="Number of primary publications"
  
)

years <- as.numeric(names(yearlyPrimary))
rect(
  ytop=yearlyPrimary, 
  ybottom=0, 
  xleft=years-0.1, 
  xright=years+0.1,
  col=primaryCol, border=NA)

abline(v=1998, lwd=2, lty=2)

dev.off()

